==> spring-cloud-contract-verifier-2.2.0.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/dsl/wiremock/WireMockResponseStubStrategy.java <==
package org.springframework.cloud.contract.verifier.dsl.wiremock;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@groovy.transform.TypeChecked() @groovy.transform.PackageScope() public class WireMockResponseStubStrategy
  extends org.springframework.cloud.contract.verifier.dsl.wiremock.BaseWireMockStubStrategy {
;
public WireMockResponseStubStrategy
(org.springframework.cloud.contract.spec.Contract groovyDsl, org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) {
super ((org.springframework.cloud.contract.spec.Contract)null);
}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
protected  org.springframework.cloud.contract.verifier.util.ContentType contentType(org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
@groovy.transform.PackageScope() public  com.github.tomakehurst.wiremock.http.ResponseDefinition buildClientResponseContent() { return (com.github.tomakehurst.wiremock.http.ResponseDefinition)null;}
}

==> spring-cloud-contract-verifier-2.2.2.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/dsl/wiremock/WireMockResponseStubStrategy.java <==
package org.springframework.cloud.contract.verifier.dsl.wiremock;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@groovy.transform.TypeChecked() @groovy.transform.PackageScope() public class WireMockResponseStubStrategy
  extends org.springframework.cloud.contract.verifier.dsl.wiremock.BaseWireMockStubStrategy  implements
    groovy.lang.GroovyObject {
;
public WireMockResponseStubStrategy
(org.springframework.cloud.contract.spec.Contract groovyDsl, org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) {
super ((org.springframework.cloud.contract.spec.Contract)null);
}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
protected  org.springframework.cloud.contract.verifier.util.ContentType contentType(org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
@groovy.transform.PackageScope() public  com.github.tomakehurst.wiremock.http.ResponseDefinition buildClientResponseContent() { return (com.github.tomakehurst.wiremock.http.ResponseDefinition)null;}
}
